import { useNavigate } from "react-router-dom";

export const useNavigation = () => {
    const navigate = useNavigate();

    const goToPagesAndOpenTab = (tabId: string, path: string) => {
        navigate(`${path}?tab=${tabId}`);
    };

    const goToTextsAndOpenCollapsible = (collapseId: string, path: string) => {
        navigate(`${path}?collapseId=${collapseId}`);
    };

    const goToPageWithTabAndCollapsible = ({ path, tabId, collapseId }: { path: string, tabId: string, collapseId?: string }) => {
        let url = `${path}?tab=${tabId}`;
        if (collapseId) {
            url += `&collapseId=${collapseId}`;
        }
        navigate(url);
    };

    const goToPageWithNestedTabs = ({ path, tabId, subTabId, collapseId }: { path: string, tabId: string, subTabId?: string, collapseId?: string }) => {
        let url = `${path}?tab=${tabId}`;
        if (subTabId) {
            url += `&subTab=${subTabId}`;
        }
        if (collapseId) {
            url += `&collapseId=${collapseId}`;
        }
        navigate(url);
    };

    // Erweiterte Funktion, die auch zu einer bestimmten ID innerhalb eines Tabs scrollen kann
    const goToPageWithTabAndScroll = ({ path, tabId, scrollToId }: { path: string, tabId: string, scrollToId?: string }) => {
        let url = `${path}?tab=${tabId}`;
        if (scrollToId) {
            url += `&scrollTo=${scrollToId}`;
        }
        navigate(url);

        // Führe nach der Navigation das Scrollen aus
        setTimeout(() => {
            if (scrollToId) {
                const element = document.getElementById(scrollToId);
                if (element) {
                    // Berechne die Scroll-Position, um das Element in der Mitte zu setzen
                    const viewportHeight = window.innerHeight;
                    const targetPosition = element.getBoundingClientRect().top + window.pageYOffset;
                    const scrollToPosition = targetPosition - viewportHeight / 2 + element.clientHeight / 2;

                    window.scrollTo({ top: scrollToPosition, behavior: "smooth" });
                }
            }
        }, 500); // Verzögere das Scrollen, um sicherzustellen, dass der Tab geladen ist
    };

    return { goToPagesAndOpenTab, goToTextsAndOpenCollapsible, goToPageWithTabAndCollapsible, goToPageWithNestedTabs, goToPageWithTabAndScroll };
};
